# :material-atom: - Core

This section focuses on the description of the library's most internal tools that could be used to develop new API `Interactions`.

!!! warning
    :material-hammer-wrench: - Section under construction.
